@@ -53,7 +53,7 @@ class Instance(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["InstanceProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[InstanceProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -208,7 +208,7 @@ class InstanceProps:
         if __debug__:
             def stub(
                 *,
-                data_node: typing.Union[typing.Union["RosInstance.DataNodeProperty", typing.Dict[str, typing.Any]], ros_cdk_core.IResolvable],
+                data_node: typing.Union[typing.Union[RosInstance.DataNodeProperty, typing.Dict[str, typing.Any]], ros_cdk_core.IResolvable],
                 password: typing.Union[builtins.str, ros_cdk_core.IResolvable],
                 version: typing.Union[builtins.str, ros_cdk_core.IResolvable],
                 v_switch_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
@@ -217,16 +217,16 @@ class InstanceProps:
                 enable_kibana_public: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
                 enable_public: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
                 instance_charge_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-                kibana_node: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosInstance.KibanaNodeProperty", typing.Dict[str, typing.Any]]]] = None,
+                kibana_node: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosInstance.KibanaNodeProperty, typing.Dict[str, typing.Any]]]] = None,
                 kibana_whitelist: typing.Optional[typing.Union[typing.Sequence[typing.Any], ros_cdk_core.IResolvable]] = None,
-                master_node: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosInstance.MasterNodeProperty", typing.Dict[str, typing.Any]]]] = None,
+                master_node: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosInstance.MasterNodeProperty, typing.Dict[str, typing.Any]]]] = None,
                 period: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
                 period_unit: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
                 private_whitelist: typing.Optional[typing.Union[typing.Sequence[typing.Any], ros_cdk_core.IResolvable]] = None,
                 public_whitelist: typing.Optional[typing.Union[typing.Sequence[typing.Any], ros_cdk_core.IResolvable]] = None,
                 resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-                tags: typing.Optional[typing.Sequence[typing.Union["RosInstance.TagsProperty", typing.Dict[str, typing.Any]]]] = None,
-                yml_config: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosInstance.YMLConfigProperty", typing.Dict[str, typing.Any]]]] = None,
+                tags: typing.Optional[typing.Sequence[typing.Union[RosInstance.TagsProperty, typing.Dict[str, typing.Any]]]] = None,
+                yml_config: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosInstance.YMLConfigProperty, typing.Dict[str, typing.Any]]]] = None,
                 zone_count: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
                 zone_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
             ) -> None:
@@ -522,7 +522,7 @@ class RosInstance(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosInstanceProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosInstanceProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -656,7 +656,7 @@ class RosInstance(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Union["RosInstance.DataNodeProperty", ros_cdk_core.IResolvable],
+                value: typing.Union[RosInstance.DataNodeProperty, ros_cdk_core.IResolvable],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -881,7 +881,7 @@ class RosInstance(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.KibanaNodeProperty"]],
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosInstance.KibanaNodeProperty]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -929,7 +929,7 @@ class RosInstance(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.MasterNodeProperty"]],
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosInstance.MasterNodeProperty]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -1071,7 +1071,7 @@ class RosInstance(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.List["RosInstance.TagsProperty"]],
+                value: typing.Optional[typing.List[RosInstance.TagsProperty]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -1099,7 +1099,7 @@ class RosInstance(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.YMLConfigProperty"]],
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosInstance.YMLConfigProperty]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
